@@ -40,15 +40,12 @@
 #define SUBFOLDER_DIR_NAME     "subfolders"
 #define SUBFOLDER_DIR_NAME_LEN 10
 
-#define EWS_MAPI_MSGFLAG_RN_PENDING 0x100
-
 CamelFolderInfo *
 camel_ews_utils_build_folder_info (CamelEwsStore *store,
                                    const gchar *fid)
 {
 	CamelEwsStoreSummary *ews_summary = store->summary;
 	CamelFolderInfo *fi;
-	gchar *folder_name;
 
 	fi = camel_folder_info_new ();
 	fi->full_name = camel_ews_store_summary_get_folder_full_name (
@@ -61,14 +58,14 @@ camel_ews_utils_build_folder_info (CamelEwsStore *store,
 		return NULL;
 	}
 
-	folder_name = camel_ews_store_summary_get_folder_name (ews_summary, fid, NULL);
-
-	fi->display_name = e_ews_folder_utils_unescape_name (folder_name);
-	fi->flags = camel_ews_store_summary_get_folder_flags (ews_summary, fid, NULL);
-	fi->unread = camel_ews_store_summary_get_folder_unread (ews_summary, fid, NULL);
-	fi->total = camel_ews_store_summary_get_folder_total (ews_summary, fid, NULL);
-
-	g_free (folder_name);
+	fi->display_name = camel_ews_store_summary_get_folder_name (
+		ews_summary, fid, NULL);
+	fi->flags = camel_ews_store_summary_get_folder_flags (
+		ews_summary, fid, NULL);
+	fi->unread = camel_ews_store_summary_get_folder_unread (
+		ews_summary, fid, NULL);
+	fi->total = camel_ews_store_summary_get_folder_total (
+		ews_summary, fid, NULL);
 
 	if (!(fi->flags & CAMEL_FOLDER_TYPE_MASK)) {
 		switch (camel_ews_store_summary_get_folder_type (ews_summary, fid, NULL)) {
@@ -421,16 +418,6 @@ ews_utils_rename_label (const gchar *cat,
 	return cat;
 }
 
-static gboolean
-ews_utils_is_system_user_flag (const gchar *name)
-{
-	if (!name)
-		return FALSE;
-
-	return g_str_equal (name, "receipt-handled") ||
-		g_str_equal (name, "$has-cal");
-}
-
 void
 ews_utils_replace_server_user_flags (ESoapMessage *msg,
                                      CamelEwsMessageInfo *mi)
@@ -444,12 +431,14 @@ ews_utils_replace_server_user_flags (ESoapMessage *msg,
 		const gchar *n = ews_utils_rename_label (flag->name, 0);
 		if (*n == '\0')
 			continue;
-
-		/* Skip evolution-defined flags which are not supposed to
-		   be categories on an Exchange server */
-		if (ews_utils_is_system_user_flag (n))
+		/* This is a mismatch between evolution flags and
+		 * exchange categories.  Evolution uses a
+		 * receipt-handled flag for message receipts, which we
+		 * don't want showing up in the categories, so
+		 * silently drop it here */
+		if (strcmp (n, "receipt-handled") == 0 ||
+		    strcmp (n, "$has-cal") == 0)
 			continue;
-
 		e_ews_message_write_string_parameter (msg, "String", NULL, n);
 	}
 }
@@ -464,16 +453,14 @@ ews_utils_merge_server_user_flags (EEwsItem *item,
 
 	/* transfer camel flags to a list */
 	for (flag = camel_message_info_user_flags (&mi->info); flag;
-	     flag = flag->next) {
-		if (!ews_utils_is_system_user_flag (flag->name))
-			list = g_slist_prepend (list, (gchar *) flag->name);
-	}
+	     flag = flag->next)
+		list = g_slist_append (list, (gchar *) flag->name);
 
+	/* we're transferring from server only, so just dump them */
 	for (p = list; p; p = p->next) {
-		/* remove custom user flags */
-		camel_flag_set (&mi->info.user_flags, p->data, FALSE);
+		camel_flag_set (&mi->info.user_flags, p->data, 0);
 	}
-
+	//g_slist_foreach (list, (GFunc) g_free, NULL);
 	g_slist_free (list);
 
 	/* now transfer over all the categories */
@@ -484,12 +471,12 @@ ews_utils_merge_server_user_flags (EEwsItem *item,
 	}
 }
 
-static guint32
+static gint
 ews_utils_get_server_flags (EEwsItem *item)
 {
 	gboolean flag;
 	EwsImportance importance;
-	guint32 server_flags = 0, msg_flags;
+	gint server_flags = 0;
 
 	e_ews_item_is_read (item, &flag);
 	if (flag)
@@ -513,10 +500,6 @@ ews_utils_get_server_flags (EEwsItem *item)
 	if (importance == EWS_ITEM_HIGH)
 		server_flags |= CAMEL_MESSAGE_FLAGGED;
 
-	msg_flags = e_ews_item_get_message_flags (item);
-	if ((msg_flags & EWS_MAPI_MSGFLAG_RN_PENDING) != 0)
-		server_flags |= CAMEL_EWS_MESSAGE_MSGFLAG_RN_PENDING;
-
 	/* TODO Update replied flags */
 
 	return server_flags;
@@ -724,23 +707,6 @@ camel_ews_utils_update_follow_up_flags (EEwsItem *item,
 	return changed;
 }
 
-static gboolean
-camel_ews_utils_update_read_receipt_flags (EEwsItem *item,
-					   CamelMessageInfo *info,
-					   guint32 server_flags,
-					   gboolean requests_read_receipt)
-{
-	gboolean changed = FALSE;
-
-	/* PidTagReadReceiptRequested */
-	if ((requests_read_receipt || e_ews_item_get_extended_property_as_boolean (item, NULL, 0x0029, NULL)) &&
-	    (server_flags & CAMEL_EWS_MESSAGE_MSGFLAG_RN_PENDING) == 0) {
-		changed = camel_message_info_set_user_flag (info, "receipt-handled", TRUE) || changed;
-	}
-
-	return changed;
-}
-
 void
 camel_ews_utils_sync_updated_items (CamelEwsFolder *ews_folder,
                                     GSList *items_updated)
@@ -763,27 +729,19 @@ camel_ews_utils_sync_updated_items (CamelEwsFolder *ews_folder,
 		}
 
 		id = e_ews_item_get_id (item);
-		if (!id) {
-			g_warning ("%s: Missing ItemId for item type %d (subject:%s)", G_STRFUNC, e_ews_item_get_item_type (item),
-				e_ews_item_get_subject (item) ? e_ews_item_get_subject (item) : "???");
-			g_object_unref (item);
-			continue;
-		}
-
-		mi = (CamelEwsMessageInfo *) camel_folder_summary_get (folder->summary, id->id);
+		mi = (CamelEwsMessageInfo *)
+			camel_folder_summary_get (folder->summary, id->id);
 		if (mi) {
-			guint32 server_flags;
+			gint server_flags;
 			gboolean changed, was_changed;
 
 			was_changed = (mi->info.flags & CAMEL_MESSAGE_FOLDER_FLAGGED) != 0;
-
 			server_flags = ews_utils_get_server_flags (item);
 			ews_utils_merge_server_user_flags (item, mi);
 			changed = camel_ews_update_message_info_flags (
 				folder->summary, (CamelMessageInfo *) mi,
 				server_flags, NULL);
 			changed = camel_ews_utils_update_follow_up_flags (item, (CamelMessageInfo *) mi) || changed;
-			changed = camel_ews_utils_update_read_receipt_flags (item, (CamelMessageInfo *) mi, server_flags, FALSE) || changed;
 
 			if (changed)
 				camel_folder_change_info_change_uid (ci, mi->info.uid);
@@ -837,7 +795,7 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		EEwsItemType item_type;
 		const GSList *to, *cc;
 		const gchar *msg_headers;
-		gboolean has_attachments, found_property, message_requests_read_receipt = FALSE;
+		gboolean has_attachments, found_property;
 		guint32 server_flags;
 
 		if (!item)
@@ -849,14 +807,8 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		}
 
 		id = e_ews_item_get_id (item);
-		if (!id) {
-			g_warning ("%s: Missing ItemId for item type %d (subject:%s)", G_STRFUNC, e_ews_item_get_item_type (item),
-				e_ews_item_get_subject (item) ? e_ews_item_get_subject (item) : "???");
-			g_object_unref (item);
-			continue;
-		}
-
-		mi = (CamelEwsMessageInfo *) camel_folder_summary_get (folder->summary, id->id);
+		mi = (CamelEwsMessageInfo *)
+			camel_folder_summary_get (folder->summary, id->id);
 		if (mi) {
 			camel_message_info_unref (mi);
 			g_object_unref (item);
@@ -881,11 +833,8 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 			camel_mime_parser_scan_from (parser, FALSE);
 			g_object_unref (stream);
 
-			if (camel_mime_part_construct_from_parser_sync (part, parser, NULL, NULL)) {
+			if (camel_mime_part_construct_from_parser_sync (part, parser, NULL, NULL))
 				mi = (CamelEwsMessageInfo *) camel_folder_summary_info_new_from_header (folder->summary, part->headers);
-				if (camel_header_raw_find (&(part->headers), "Disposition-Notification-To", NULL))
-					message_requests_read_receipt = TRUE;
-			}
 
 			g_object_unref (parser);
 			g_object_unref (part);
@@ -944,9 +893,9 @@ camel_ews_utils_sync_created_items (CamelEwsFolder *ews_folder,
 		mi->server_flags = server_flags;
 
 		camel_ews_utils_update_follow_up_flags (item, (CamelMessageInfo *) mi);
-		camel_ews_utils_update_read_receipt_flags (item, (CamelMessageInfo *) mi, server_flags, message_requests_read_receipt);
 
-		camel_folder_summary_add (folder->summary, (CamelMessageInfo *) mi);
+		camel_folder_summary_add (
+			folder->summary, (CamelMessageInfo *) mi);
 
 		/* camel_folder_summary_add() sets folder_flagged flag
 		 * on the message info, but this is a fresh item downloaded
