@@ -76,35 +76,6 @@ G_DEFINE_TYPE_WITH_CODE (
 	G_IMPLEMENT_INTERFACE (
 		CAMEL_TYPE_NETWORK_SETTINGS, NULL))
 
-static gboolean
-ews_settings_transform_host_url_to_host_cb (GBinding *binding,
-					    const GValue *host_url_value,
-					    GValue *host_value,
-					    gpointer user_data)
-{
-	const gchar *host_url;
-
-	host_url = g_value_get_string (host_url_value);
-	if (host_url && *host_url) {
-		SoupURI *uri;
-
-		uri = soup_uri_new (host_url);
-		if (uri) {
-			const gchar *host;
-
-			host = soup_uri_get_host (uri);
-			if (!host || !*host)
-				host = "";
-
-			g_value_set_string (host_value, host);
-
-			soup_uri_free (uri);
-		}
-	}
-
-	return TRUE;
-}
-
 static void
 ews_settings_set_property (GObject *object,
                             guint property_id,
@@ -610,51 +581,6 @@ camel_ews_settings_init (CamelEwsSettings *settings)
 {
 	settings->priv = CAMEL_EWS_SETTINGS_GET_PRIVATE (settings);
 	g_mutex_init (&settings->priv->property_lock);
-
-	g_object_bind_property_full (settings, "hosturl",
-				     settings, "host",
-				     G_BINDING_DEFAULT,
-				     ews_settings_transform_host_url_to_host_cb,
-				     NULL,
-				     NULL,
-				     NULL);
-}
-
-/**
- * camel_ews_settings_get_auth_mechanism:
- * @settings: a #CamelEwsSettings
- *
- * Returns a #EwsAuthType enum value indicating which authentication
- * method to use.
- *
- * Returns: authentication method to use for this account
- *
- * Since: 3.14
- **/
-EwsAuthType
-camel_ews_settings_get_auth_mechanism (CamelEwsSettings *settings)
-{
-	EwsAuthType result;
-	gchar *auth_mech = NULL;
-
-	g_return_val_if_fail (CAMEL_IS_EWS_SETTINGS (settings), FALSE);
-
-	g_object_get (G_OBJECT (settings), "auth-mechanism", &auth_mech, NULL);
-
-	/* The value for "NTLM" is a special case. Sometimes it's NULL,
-	 * and sometimes it's "". But never "NTLM". No, that would be too
-	 * simple. (I think it's for backward-compatibility with old
-	 * profiles, so they default to NTLM). */
-	if (auth_mech && g_ascii_strcasecmp (auth_mech, "PLAIN") == 0)
-		result = EWS_AUTH_TYPE_BASIC;
-	else if (auth_mech && g_ascii_strcasecmp (auth_mech, "GSSAPI") == 0)
-		result = EWS_AUTH_TYPE_GSSAPI;
-	else
-		result = EWS_AUTH_TYPE_NTLM;
-
-	g_free (auth_mech);
-
-	return result;
 }
 
 /**
